@@ -31,7 +31,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.37';
+our $VERSION = '2.38';
 
 =head1 SYNOPSIS
 
@@ -170,7 +170,7 @@ has afterok => (
 
 =head2 cpus_per_task
 
-slurm item --cpus_per_task defaults to 8, which is probably fine
+slurm item --cpus_per_task defaults to 4, which is probably fine
 
 =cut
 
@@ -393,7 +393,7 @@ has 'cmd_counter' => (
     is      => 'ro',
     isa     => 'Num',
     required => 1,
-    default => 1,
+    default => 0,
     handles => {
         inc_cmd_counter   => 'inc',
         dec_cmd_counter   => 'dec',
@@ -596,6 +596,8 @@ sub check_files{
     my($self) = @_;
     my($t);
 
+    $DB::single=2;
+
     $t = $self->outdir;
     $t =~ s/\/$//g;
     $self->outdir($t);
@@ -604,6 +606,7 @@ sub check_files{
     make_path($self->outdir) if ! -d $self->outdir;
 
     $self->get_nodes;
+    $DB::single=2;
 }
 
 =head2 get_nodes
@@ -617,6 +620,7 @@ If the nodelist is supplied partition must be supplied
 sub get_nodes{
     my($self) = @_;
 
+    $DB::single=2;
 #    #Fix - had this backwards
     if($self->nodelist && !$self->partition){
         print "If you define a nodelist you must define a partition!\n";
@@ -739,6 +743,7 @@ sub parse_file_slurm{
         next if $line =~ m/^#/;
 
         $DB::single=2;
+
         #Do a sanity check for nohup
         if($line =~ m/^nohup/){
             die print "You cannot submit jobs to the queue using nohup! Please remove nohup and try again.\n";
@@ -848,23 +853,8 @@ sub process_batch{
         $ok = join(":", @{$self->jobref->[-2]}) if $self->jobref->[-2];
     }
 
-    #Giving outdir/jobname doesn't work unless a full file path is supplied
-    #Need to get absolute path going on...
-#    $self->cmdfile($self->jobname."_batch".$self->batch_counter.".in");
-
-    if($self->use_gnuparallel){
-        $command = "cd ".getcwd()."\n";
-        $command .= "cat ".$self->cmdfile." | parallelparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter."\n";
-    }
-    elsif($self->use_threads){
-        $command = "cd ".getcwd()."\n"; #Go back to the working directory just to be safe
-        $command .= "paralellrunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
-    }
-    elsif($self->use_processes){
-        $command = "cd ".getcwd()."\n";
-        $command .= "mcerunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
-    }
 
+    $command = $self->process_batch_command();
     $DB::single=2;
 
     $self->template->process($self->template_file,
@@ -885,6 +875,41 @@ sub process_batch{
     $self->submit_slurm if $self->submit_to_slurm;
 }
 
+=head2 process_batch_command
+
+splitting this off from the main command
+
+=cut
+
+#TODO add support for custom commands
+
+sub process_batch_command {
+    my($self) = @_;
+    my $command;
+
+    #Giving outdir/jobname doesn't work unless a full file path is supplied
+    #Need to get absolute path going on...
+    #$self->cmdfile($self->jobname."_batch".$self->batch_counter.".in");
+
+    if($self->use_gnuparallel){
+        $command = "cd ".getcwd()."\n";
+        $command .= "cat ".$self->cmdfile." | parallelparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter."\n";
+    }
+    elsif($self->use_threads){
+        $command = "cd ".getcwd()."\n"; #Go back to the working directory just to be safe
+        $command .= "paralellrunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
+    }
+    elsif($self->use_processes){
+        $command = "cd ".getcwd()."\n";
+        $command .= "mcerunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
+    }
+    else{
+        die print "None of the job processes were chosen!\n";
+    }
+
+    return $command;
+}
+
 =head2 submit_slurm()
 
 Submit jobs to slurm queue using sbatch.
